<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Illuminate\Support\Facades\Lang;


class SendConfirmEmail extends Notification
{
    use Queueable;
    public $abstract_id;
    public $abstract_title;

    /**
     * Create a new notification instance.
     */
    public function __construct($id,$title)
    {
        $this->abstract_id=$id;
        $this->abstract_title=$title;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }

    /**
     * Get the mail representation of the notification.
     */
    public function toMail(object $notifiable): MailMessage
    {
        return (new MailMessage)
                    ->subject(Lang::get('Abstract submission notification'))
                    ->greeting(Lang::get('Dear '.$notifiable->name))
                    ->line('On behalf of the Sri Lanka Society of Nephrology we thank you for your abstract submission.')
                    ->line('Your submission has been received and will proceed to the review stage.')
                    ->line('Please note that this notification is only sent to the corresponding author, so we ask you to share this information with any co-authors.')
                    ->line('The details of your abstract are given below.')
                    ->line('Title: '.$this->abstract_title)
                    ->line('Abstract ID: SLSON'.$this->abstract_id)
                    ->line('To submit a new abstract, please login to your account using https://platform.slson.lk/platform/public/abstractPortal. Please note that one author is allowed to submit a maximum of three (03) abstracts only. ')
                    ->line('If you have any questions regarding the conference or your submission, feel free to contact us on  ')
                    ->line('You will be notified of the outcome of your abstract submission in due course.')
                    ->line(Lang::get('Thank you.'));
    }

    /**
     * Get the array representation of the notification.
     *
     * @return array<string, mixed>
     */
    public function toArray(object $notifiable): array
    {
        return [
            //
        ];
    }
}
